resttools.make_repeated_rests_from_time_signatures
==================================================

.. autofunction:: abjad.tools.resttools.make_repeated_rests_from_time_signatures.make_repeated_rests_from_time_signatures
